@@ -10,16 +10,21 @@
 
 #include "config.h"
 #include "sddmdata.h"
-#include "sddmsettings.h"
+
 #include "sessionmodel.h"
-#include "themesmodel.h"
+
 #include "usersmodel.h"
 
 #include <QApplication>
 #include <QDir>
 
 #include <KAboutData>
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/ExecuteJob>
+#else
 #include <KAuthExecuteJob>
+#endif
 #include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
 #include <KPluginFactory>
